Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5453)

Unified Diff: chrome/browser/chromeos/arc/arc_policy_bridge.cc

Issue 1877803002: Rename ArcApplicationPolicy to ArcPolicy (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@managed_cros
Patch Set: Updated histograms.xml Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/arc/arc_policy_bridge.cc
diff --git a/chrome/browser/chromeos/arc/arc_policy_bridge.cc b/chrome/browser/chromeos/arc/arc_policy_bridge.cc
index a65026175e9f26089a926191c9e6f8d666439852..a7054556eebc0a4202f0c24c6e4212230b082c36 100644
--- a/chrome/browser/chromeos/arc/arc_policy_bridge.cc
+++ b/chrome/browser/chromeos/arc/arc_policy_bridge.cc
@@ -47,10 +47,10 @@ void AddPolicy(const std::string arc_policy_name,
std::string GetFilteredJSONPolicies(const policy::PolicyMap& policy_map) {
base::DictionaryValue filtered_policies;
// Parse ArcApplicationPolicy as JSON string before adding other policies to
// the dictionary.
const base::Value* const app_policy_value =
- policy_map.GetValue(policy::key::kArcApplicationPolicy);
+ policy_map.GetValue(policy::key::kArcPolicy);
if (app_policy_value) {
std::string app_policy_string;
app_policy_value->GetAsString(&app_policy_string);
@@ -62,7 +62,7 @@ std::string GetFilteredJSONPolicies(const policy::PolicyMap& policy_map) {
// JSONStringValues which are based on StringPiece instead of string.
filtered_policies.MergeDictionary(app_policy_dict.get());
} else {
- LOG(ERROR) << "Value of ArcApplicationPolicy has invalid format: "
+ LOG(ERROR) << "Value of ArcPolicy has invalid format: "
<< app_policy_string;
}
}
@@ -47,10 +47,10 @@ void AddPolicy(const std::string arc_policy_name,
std::string GetFilteredJSONPolicies(const policy::PolicyMap& policy_map) {
base::DictionaryValue filtered_policies;
- // Parse ArcApplicationPolicy as JSON string before adding other policies to
- // the dictionary.
+ // Parse ArcPolicy as JSON string before adding other policies to the
+ // dictionary.
const base::Value* const app_policy_value =

Powered by Google App Engine
This is Rietveld 408576698